@@ -174,6 +174,22 @@ class Bamboo(AtlassianRestAPI):
         resource = "rest/api/latest/plan/{}".format(plan_key)
         return self.get(resource, params=params)
 
+    def search_plans(self, search_term, fuzzy=True, start_index=0, max_results=25):
+        """
+        Search plans by name
+        :param search_term: str
+        :param fuzzy: bool optional
+        :param start_index: optional
+        :param max_results: optional
+        :return: GET request
+        """
+
+        resource = "rest/api/latest/search/plans"
+        return self.get(
+            resource,
+            params={"fuzzy": fuzzy, "searchTerm": search_term, "max-results": max_results, "start-index": start_index},
+        )
+
     def delete_plan(self, plan_key):
         """
         Marks plan for deletion. Plan will be deleted by a batch job.
@@ -636,6 +652,10 @@ class Bamboo(AtlassianRestAPI):
         resource = "deploy/project/{}".format(project_id)
         return self.get(self.resource_url(resource))
 
+    def delete_deployment_project(self, project_id):
+        resource = "deploy/project/{}".format(project_id)
+        return self.delete(self.resource_url(resource))
+
     def deployment_environment_results(self, env_id, expand=None, max_results=25):
         resource = "deploy/environment/{environmentId}/results".format(environmentId=env_id)
         params = {"max-result": max_results, "start-index": 0}
@@ -1095,3 +1115,60 @@ class Bamboo(AtlassianRestAPI):
         ).headers["upm-token"]
         url = "rest/plugins/1.0/?token={upm_token}".format(upm_token=upm_token)
         return self.post(url, files=files, headers=self.no_check_headers)
+
+    def get_elastic_instance_logs(self, instance_id):
+        """
+        Get logs from an EC2 instance
+        :param instance_id:
+        :return:
+        """
+        resource = "/elasticInstances/instance/{instance_id}/logs".format(instance_id=instance_id)
+        return self.get(self.resource_url(resource))
+
+    def get_elastic_configurations(self):
+        """
+        Get list of all elastic configurations
+        :return:
+        """
+        resource = "elasticConfiguration"
+        return self.get(self.resource_url(resource))
+
+    def create_elastic_configuration(self, json):
+        """
+        Create an elastic configuration
+        :param json:
+        :return:
+        """
+        resource = "elasticConfiguration"
+        return self.post(self.resource_url(resource), json=json)
+
+    def get_elastic_configuration(self, configuration_id):
+        """
+        Get informatin of an elastic configuration
+        :param configuration_id:
+        :return:
+        """
+
+        resource = "elasticConfiguration/{configuration_id}".format(configuration_id=configuration_id)
+        return self.get(self.resource_url(resource))
+
+    def update_elastic_configuration(self, configuration_id, data):
+        """
+        Update an elastic configuration
+        :param configuration_id:
+        :param data:
+        :return:
+        """
+
+        resource = "elasticConfiguration/{configuration_id}".format(configuration_id=configuration_id)
+        return self.put(self.resource_url(resource), data=data)
+
+    def delete_elastic_configuration(self, configuration_id):
+        """
+        Delete an elastic configuration
+        :param configuration_id:
+        :return:
+        """
+
+        resource = "elasticConfiguration/{configuration_id}".format(configuration_id=configuration_id)
+        return self.delete(self.resource_url(resource))
