@@ -3,7 +3,7 @@ import logging
 from json import dumps
 
 import requests
-from oauthlib.oauth1 import SIGNATURE_RSA
+from oauthlib.oauth1 import SIGNATURE_RSA_SHA512
 from requests import HTTPError
 from requests_oauthlib import OAuth1, OAuth2
 from six.moves.urllib.parse import urlencode
@@ -103,7 +103,7 @@ class AtlassianRestAPI(object):
         oauth = OAuth1(
             oauth_dict["consumer_key"],
             rsa_key=oauth_dict["key_cert"],
-            signature_method=SIGNATURE_RSA,
+            signature_method=SIGNATURE_RSA_SHA512,
             resource_owner_key=oauth_dict["access_token"],
             resource_owner_secret=oauth_dict["access_token_secret"],
         )
@@ -190,6 +190,7 @@ class AtlassianRestAPI(object):
         files=None,
         trailing=None,
         absolute=False,
+        advanced_mode=False,
     ):
         """
 
@@ -203,6 +204,7 @@ class AtlassianRestAPI(object):
         :param files:
         :param trailing: bool
         :param absolute: bool, OPTIONAL: Do not prefix url, url is absolute
+        :param advanced_mode: bool, OPTIONAL: Return the raw response
         :return:
         """
         url = self.url_joiner(None if absolute else self.url, path, trailing)
@@ -237,7 +239,7 @@ class AtlassianRestAPI(object):
 
         log.debug("HTTP: {} {} -> {} {}".format(method, path, response.status_code, response.reason))
         log.debug("HTTP: Response text -> {}".format(response.text))
-        if self.advanced_mode:
+        if self.advanced_mode or advanced_mode:
             return response
 
         self.raise_for_status(response)
@@ -277,6 +279,7 @@ class AtlassianRestAPI(object):
             headers=headers,
             trailing=trailing,
             absolute=absolute,
+            advanced_mode=advanced_mode,
         )
         if self.advanced_mode or advanced_mode:
             return response
@@ -304,6 +307,14 @@ class AtlassianRestAPI(object):
         advanced_mode=False,
     ):
         """
+        :param path:
+        :param data:
+        :param json:
+        :param headers:
+        :param files:
+        :param params:
+        :param trailing:
+        :param absolute:
         :param advanced_mode: bool, OPTIONAL: Return the raw response
         :return: if advanced_mode is not set - returns dictionary. If it is set - returns raw response.
         """
@@ -334,6 +345,13 @@ class AtlassianRestAPI(object):
         advanced_mode=False,
     ):
         """
+        :param path: Path of request
+        :param data:
+        :param headers: adjusted headers, usually it's default
+        :param files:
+        :param trailing:
+        :param params:
+        :param absolute:
         :param advanced_mode: bool, OPTIONAL: Return the raw response
         :return: if advanced_mode is not set - returns dictionary. If it is set - returns raw response.
         """
@@ -363,6 +381,12 @@ class AtlassianRestAPI(object):
     ):
         """
         Deletes resources at given paths.
+        :param path:
+        :param data:
+        :param headers:
+        :param params:
+        :param trailing:
+        :param absolute:
         :param advanced_mode: bool, OPTIONAL: Return the raw response
         :rtype: dict
         :return: Empty dictionary to have consistent interface.
@@ -399,7 +423,8 @@ class AtlassianRestAPI(object):
                     error_msg = "\n".join(
                         j.get("errorMessages", list()) + [k + ": " + v for k, v in j.get("errors", dict()).items()]
                     )
-            except Exception:
+            except Exception as e:
+                log.error(e)
                 response.raise_for_status()
             else:
                 raise HTTPError(error_msg, response=response)
